@@ -7,12 +7,12 @@ Hash tree dispatch for L<Apache2::Controller::Dispatch>
 
 =head1 VERSION
 
-Version 1.000.110
+Version 1.000.111
 
 =cut
 
 use version;
-our $VERSION = version->new('1.000.110');
+our $VERSION = version->new('1.000.111');
 
 =head1 SYNOPSIS
 
@@ -268,11 +268,11 @@ L<Apache2::Controller>
 
 =head1 AUTHOR
 
-Mark Hedges, C<hedges +(a t)| scriptdolphin.org>
+Mark Hedges, C<hedges +(a t)| formdata.biz>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 Mark Hedges.  CPAN: markle
+Copyright 2008-2010 Mark Hedges.  CPAN: markle
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
