@@ -7,12 +7,12 @@ dispatch to controllers mapped by files in primary A2C_Render_Template_Path.
 
 =head1 VERSION
 
-Version 1.000.110
+Version 1.000.111
 
 =cut
 
 use version;
-our $VERSION = version->new('1.000.110');
+our $VERSION = version->new('1.000.111');
 
 =head1 SYNOPSIS
 
@@ -117,11 +117,11 @@ L<Apache2::Controller>
 
 =head1 AUTHOR
 
-Mark Hedges, C<hedges +(a t)- scriptdolphin.org>
+Mark Hedges, C<hedges +(a t)- formdata.biz>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 Mark Hedges.  CPAN: markle
+Copyright 2008-2010 Mark Hedges.  CPAN: markle
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
