@@ -6,12 +6,12 @@ Apache2::Controller::Render::Template - A2C render() with Template Toolkit
 
 =head1 VERSION
 
-Version 1.000.110
+Version 1.000.111
 
 =cut
 
 use version;
-our $VERSION = version->new('1.000.110');
+our $VERSION = version->new('1.000.111');
 
 =head1 SYNOPSIS
 
@@ -518,11 +518,11 @@ L<Apache2::Controller::X>
 
 =head1 AUTHOR
 
-Mark Hedges, C<< <hedges at--! scriptdolphin.org> >>
+Mark Hedges, C<< <hedges at--! formdata.biz> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 Mark Hedges, all rights reserved.
+Copyright 2008-2010 Mark Hedges, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
