@@ -8,12 +8,12 @@ Apache2::Controller::X - Exception::Class hierarchy for Apache2::Controller
 
 =head1 VERSION
 
-Version 1.000.110
+Version 1.000.111
 
 =cut
 
 use version;
-our $VERSION = version->new('1.000.110');
+our $VERSION = version->new('1.000.111');
 
 =head1 SYNOPSIS
 
@@ -150,11 +150,11 @@ L<Apache2::Controller::NonResponseRequest>
 
 =head1 AUTHOR
 
-Mark Hedges, C<< <hedges ||at scriptdolphin.org> >>
+Mark Hedges, C<< <hedges ||at formdata.biz> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 Mark Hedges, all rights reserved.
+Copyright 2008-2010 Mark Hedges, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
